pub struct AddMember { /* private fields */ }builder only.Expand description
A builder to add parameters when using GuildId::add_member.
Implementations
Sourceimpl AddMember
impl AddMember
Sourcepub fn new(access_token: String) -> Self
pub fn new(access_token: String) -> Self
Constructs a new builder with the given access token, leaving all other fields empty.
Sourcepub fn access_token(self, access_token: impl Into<String>) -> Self
pub fn access_token(self, access_token: impl Into<String>) -> Self
Sets the OAuth2 access token for this request, replacing the current one.
Requires the access token to have the guilds.join scope granted.
Sourcepub fn nickname(self, nickname: impl Into<String>) -> Self
pub fn nickname(self, nickname: impl Into<String>) -> Self
Sets the member’s nickname.
Requires the Manage Nicknames permission.
Sourcepub fn roles(self, roles: impl IntoIterator<Item = impl Into<RoleId>>) -> Self
pub fn roles(self, roles: impl IntoIterator<Item = impl Into<RoleId>>) -> Self
Sets the list of roles that the member should have.
Requires the Manage Roles permission.
Sourcepub fn mute(self, mute: bool) -> Self
pub fn mute(self, mute: bool) -> Self
Whether to mute the member.
Requires the Mute Members permission.
Sourcepub fn deafen(self, deafen: bool) -> Self
pub fn deafen(self, deafen: bool) -> Self
Whether to deafen the member.
Requires the Deafen Members permission.