#[non_exhaustive]pub enum Reason {
Unknown,
User(String),
Log(String),
UserAndLog {
user: String,
log: String,
},
}👎Deprecated: The standard framework is deprecated, and will be removed in 0.13. Please migrate to
poise for command handlingAvailable on crate features
framework and standard_framework only.Expand description
This type describes why a check has failed.
Note: The bot-developer is supposed to process this enum as the framework is not. It
solely serves as a way to inform a user about why a check has failed and for the developer to
log given failure (e.g. bugs or statistics) occurring in Checks.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Unknown
👎Deprecated: The standard framework is deprecated, and will be removed in 0.13. Please migrate to
poise for command handlingNo information on the failure.
User(String)
👎Deprecated: The standard framework is deprecated, and will be removed in 0.13. Please migrate to
poise for command handlingInformation dedicated to the user.
Log(String)
👎Deprecated: The standard framework is deprecated, and will be removed in 0.13. Please migrate to
poise for command handlingInformation purely for logging purposes.
UserAndLog
👎Deprecated: The standard framework is deprecated, and will be removed in 0.13. Please migrate to
poise for command handlingInformation for the user but also for logging purposes.