DispatchError

Enum DispatchError 

#[non_exhaustive]
pub enum DispatchError {
Show 13 variants CheckFailed(&'static str, Reason), Ratelimited(RateLimitInfo), CommandDisabled, BlockedUser, BlockedGuild, BlockedChannel, OnlyForDM, OnlyForGuilds, OnlyForOwners, LackingRole, LackingPermissions(Permissions), NotEnoughArguments { min: u16, given: usize, }, TooManyArguments { max: u16, given: usize, },
}
👎Deprecated: The standard framework is deprecated, and will be removed in 0.13. Please migrate to poise for command handling
Available on crate features framework and standard_framework only.
An enum representing all possible fail conditions under which a command won’t be executed.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


CheckFailed(&'static str, Reason)

👎Deprecated: The standard framework is deprecated, and will be removed in 0.13. Please migrate to poise for command handling

When a custom function check has failed.



Ratelimited(RateLimitInfo)

👎Deprecated: The standard framework is deprecated, and will be removed in 0.13. Please migrate to poise for command handling

When the command caller has exceeded a ratelimit bucket.



CommandDisabled

👎Deprecated: The standard framework is deprecated, and will be removed in 0.13. Please migrate to poise for command handling

When the requested command is disabled in bot configuration.



BlockedUser

👎Deprecated: The standard framework is deprecated, and will be removed in 0.13. Please migrate to poise for command handling

When the user is blocked in bot configuration.



BlockedGuild

👎Deprecated: The standard framework is deprecated, and will be removed in 0.13. Please migrate to poise for command handling

When the guild or its owner is blocked in bot configuration.



BlockedChannel

👎Deprecated: The standard framework is deprecated, and will be removed in 0.13. Please migrate to poise for command handling

When the channel blocked in bot configuration.



OnlyForDM

👎Deprecated: The standard framework is deprecated, and will be removed in 0.13. Please migrate to poise for command handling

When the requested command can only be used in a direct message or group channel.



OnlyForGuilds

👎Deprecated: The standard framework is deprecated, and will be removed in 0.13. Please migrate to poise for command handling

When the requested command can only be ran in guilds, or the bot doesn’t support DMs.



OnlyForOwners

👎Deprecated: The standard framework is deprecated, and will be removed in 0.13. Please migrate to poise for command handling

When the requested command can only be used by bot owners.



LackingRole

👎Deprecated: The standard framework is deprecated, and will be removed in 0.13. Please migrate to poise for command handling

When the requested command requires one role.



LackingPermissions(Permissions)

👎Deprecated: The standard framework is deprecated, and will be removed in 0.13. Please migrate to poise for command handling

When the command requester lacks specific required permissions.



NotEnoughArguments

👎Deprecated: The standard framework is deprecated, and will be removed in 0.13. Please migrate to poise for command handling

When there are too few arguments.

Fields

min: u16
👎Deprecated: The standard framework is deprecated, and will be removed in 0.13. Please migrate to poise for command handling
given: usize
👎Deprecated: The standard framework is deprecated, and will be removed in 0.13. Please migrate to poise for command handling


TooManyArguments

👎Deprecated: The standard framework is deprecated, and will be removed in 0.13. Please migrate to poise for command handling

When there are too many arguments.

Fields

max: u16
👎Deprecated: The standard framework is deprecated, and will be removed in 0.13. Please migrate to poise for command handling
given: usize
👎Deprecated: The standard framework is deprecated, and will be removed in 0.13. Please migrate to poise for command handling