[−][src]Struct serenity::model::guild::Member
Information about a member of a guild.
Fields
deaf: boolIndicator of whether the member can hear in voice channels.
guild_id: GuildIdThe unique Id of the guild that the member is a part of.
joined_at: Option<DateTime<FixedOffset>>Timestamp representing the date when the member joined.
mute: boolIndicator of whether the member can speak in voice channels.
nick: Option<String>The member's nickname, if present.
Can't be longer than 32 characters.
roles: Vec<RoleId>Vector of Ids of Roles given to the member.
user: Arc<RwLock<User>>Attached User struct.
Methods
impl Member[src]
pub fn add_role<R: Into<RoleId>>(&mut self, role_id: R) -> Result<()>[src]
Adds a Role to the member, editing its roles in-place if the request
was successful.
Note: Requires the Manage Roles permission.
pub fn add_roles(&mut self, role_ids: &[RoleId]) -> Result<()>[src]
Adds one or multiple Roles to the member, editing
its roles in-place if the request was successful.
Note: Requires the Manage Roles permission.
pub fn ban<BO: BanOptions>(&self, ban_options: &BO) -> Result<()>[src]
Ban the member from its guild, deleting the last X number of days' worth of messages.
Note: Requires the Ban Members permission.
Errors
Returns a ModelError::GuildNotFound if the guild could not be
found.
pub fn colour(&self) -> Option<Colour>[src]
Determines the member's colour.
pub fn default_channel(&self) -> Option<Arc<RwLock<GuildChannel>>>[src]
Returns the "default channel" of the guild for the member.
(This returns the first channel that can be read by the member, if there isn't
one returns None)
pub fn display_name(&self) -> Cow<String>[src]
Calculates the member's display name.
The nickname takes priority over the member's username if it exists.
pub fn distinct(&self) -> String[src]
Returns the DiscordTag of a Member, taking possible nickname into account.
pub fn edit<F: FnOnce(EditMember) -> EditMember>(&self, f: F) -> Result<()>[src]
Edits the member with the given data. See Guild::edit_member for
more information.
See EditMember for the permission(s) required for separate builder
methods, as well as usage of this.
pub fn highest_role_info(&self) -> Option<(RoleId, i64)>[src]
Retrieves the ID and position of the member's highest role in the hierarchy, if they have one.
This may return None if:
- the user has roles, but they are not present in the cache for cache inconsistency reasons
- you already have a write lock to the member's guild
The "highest role in hierarchy" is defined as the role with the highest position. If two or more roles have the same highest position, then the role with the lowest ID is the highest.
pub fn kick(&self) -> Result<()>[src]
Kick the member from the guild.
Note: Requires the Kick Members permission.
Examples
Kick a member from its guild:
// assuming a `member` has already been bound match member.kick() { Ok(()) => println!("Successfully kicked member"), Err(Error::Model(ModelError::GuildNotFound)) => { println!("Couldn't determine guild of member"); }, Err(Error::Model(ModelError::InvalidPermissions(missing_perms))) => { println!("Didn't have permissions; missing: {:?}", missing_perms); }, _ => {}, }
Errors
Returns a ModelError::GuildNotFound if the Id of the member's guild
could not be determined.
If the cache is enabled, returns a ModelError::InvalidPermissions
if the current user does not have permission to perform the kick.
pub fn permissions(&self) -> Result<Permissions>[src]
Returns the guild-level permissions for the member.
Examples
// assuming there's a `member` variable gotten from anything. println!("The permission bits for the member are: {}", member.permissions().expect("permissions").bits);
Errors
Returns a ModelError::GuildNotFound if the guild the member's in could not be
found in the cache.
And/or returns ModelError::ItemMissing if the "default channel" of the guild is not
found.
pub fn remove_role<R: Into<RoleId>>(&mut self, role_id: R) -> Result<()>[src]
Removes a Role from the member, editing its roles in-place if the
request was successful.
Note: Requires the Manage Roles permission.
pub fn remove_roles(&mut self, role_ids: &[RoleId]) -> Result<()>[src]
Removes one or multiple Roles from the member.
Note: Requires the Manage Roles permission.
pub fn roles(&self) -> Option<Vec<Role>>[src]
Retrieves the full role data for the user's roles.
This is shorthand for manually searching through the CACHE.
If role data can not be found for the member, then None is returned.
pub fn unban(&self) -> Result<()>[src]
Unbans the User from the guild.
Note: Requires the Ban Members permission.
Errors
If the cache is enabled, returns a ModelError::InvalidPermissions
if the current user does not have permission to perform bans.
pub fn user_id(&self) -> UserId[src]
Retrieves the member's user ID.
This is a shortcut for accessing the user structfield, retrieving a
reader guard, and then copying its ID.
Deadlocking
This function can deadlock while retrieving a read guard to the user object if your application infinitely holds a write lock elsewhere.